@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/archs38_generic/build/staging_dir/toolchain-arc_archs_gcc-arc-2017.09-release_uClibc/share/gcc-7.1.1/python'
-libdir = '/builder/archs38_generic/build/staging_dir/toolchain-arc_archs_gcc-arc-2017.09-release_uClibc/arc-openwrt-linux-uclibc/lib'
+pythondir = '/builder/shared-workdir/build/staging_dir/toolchain-arc_archs_gcc-arc-2017.09-release_uClibc/share/gcc-7.1.1/python'
+libdir = '/builder/shared-workdir/build/staging_dir/toolchain-arc_archs_gcc-arc-2017.09-release_uClibc/arc-openwrt-linux-uclibc/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
